/**
 * Define the exit command.
 */

package extensions.generic;

import extensions.generic.*;
import java.awt.*;
import javax.swing.*;
import java.util.HashMap;
import java.util.Vector;
import java.io.*;
import javax.media.j3d.*;
import javax.vecmath.*;


public class SaveCoordCmd implements Command {
	private List list;
	private HashMap molecules;
	private Frame frame;
	
	public SaveCoordCmd(List list, HashMap molecules, Frame frame) {
		this.list = list;
		this.molecules = molecules;
		this.frame = frame;
	}
		
    public void Execute(){

     try
     {

		//FileDialog does not work with FilenameFilter
		/*
		FileDialog fd = new FileDialog(frame, "Save TXT file", FileDialog.SAVE);
	    fd.setDirectory(".");
	    //fd.setFilenameFilter(filter);
	    fd.show();
    	String filename = fd.getFile();
    	if(filename == null) {
    		System.out.println("Cancelled by user.");
            return;
        } else {
            System.out.println("You chose to open this file: " +
            filename);
        }
        */        	     

	    JFileChooser fc = new JFileChooser(".");
	    extensions.generic.CoordTxtFilter filter = 
	              new extensions.generic.CoordTxtFilter();
        fc.setFileFilter(filter);
        int returnVal = fc.showSaveDialog(frame);

        if (returnVal == JFileChooser.APPROVE_OPTION) {     
            System.out.println("You chose to open this file: " +
            fc.getSelectedFile().getName());    	
        } else {
            System.out.println("Cancelled by user.");
            return;
        }		
        String filename = fc.getSelectedFile().getName();
        
        String selectedItems[] = list.getSelectedItems();
		HashMap tmp = new HashMap();
		
	    if(selectedItems.length == 0) {
	    	System.out.println("You don't have any the selected items!!!!!!");
	    	return;
	    }	        

        FileOutputStream file = new FileOutputStream(filename);
        PrintWriter out = new PrintWriter(file);

  		for(int i=0; i<selectedItems.length; i++) {
  			
		  //for(int j=0; j<molecules.length; j++)
			//if(((String)molecules[j].get("MOLECULE_ID")).equals(selectedItems[i])) {
			    tmp = (HashMap)molecules.get(selectedItems[i]);
			    //break;
		      //}
		  
		  out.println("\n\n === "+selectedItems[i]+" === \n\n");
		  out.println("\t"+"ATOM"+"\t"+"CHARGE"+"\t"+"X"+"\t\t"+"Y"+"\t\t"+"Z");
		  out.println("\t"+"---------------------------------------------------");
		  Vector writeatom = new Vector();
		  Vector writeatomcharge = new Vector();
		  
		  writeatom = (Vector)tmp.get("atom");
		  writeatomcharge = (Vector)tmp.get("atomcharge");
		  
          TransformGroup tg = new TransformGroup();
          tg.setCapability(TransformGroup.ALLOW_TRANSFORM_WRITE);
          tg.setCapability(TransformGroup.ALLOW_TRANSFORM_READ);
          tg.setCapability(Group.ALLOW_CHILDREN_WRITE);
          tg.setCapability(Group.ALLOW_CHILDREN_READ);
          tg.setCapability(Group.ALLOW_CHILDREN_EXTEND);
          tg.setCapability(TransformGroup.ENABLE_PICK_REPORTING);
		  
          Transform3D t3d = new Transform3D();

		  int ncount = ((Integer)tmp.get("nvertex")).intValue();
		  double normaxis = ((Double)tmp.get("normaxis")).doubleValue();
		  Vector3d v[] = new Vector3d[ncount];
		            
     	  for(int k=0; k<ncount; k++) {
     	  	v[k] = new Vector3d();
     	  	tg = (TransformGroup)tmp.get((String)writeatom.elementAt(k));
            tg.getTransform( t3d );
            t3d.get( v[k] );
            
            out.println("\t"+(String)writeatom.elementAt(k)+
                        "\t"+((Float)writeatomcharge.elementAt(k)).floatValue()+
                        "\t"+v[k].x*normaxis+"\t"+v[k].y*normaxis+"\t"+v[k].z*normaxis);            
          }
        
        }       
        
        out.flush();
        file.close();
        System.out.println("Write Info into File ===> Done. ");
     }
     catch(IOException ex)
     {
         System.err.println("Can't write to `" +  ex.getMessage() + "'");
         //System.exit(1);
     }
  }

}

